@@ -49,28 +49,28 @@ from pyramid_helpers.utils import request_cache
 from pyramid_helpers.utils import resolve_dotted
 
 
-AUTH_CLIENTS = {}
+BACKENDS = {}
 
 SETTINGS_DEFAULTS = {
     'auth': {
-        'policies': ['ticket', ],
-        'mode': None,
+        'backend': None,
+        'policies': ['cookie', ],
         'get_principals': None,
         'get_user_by_username': None,
     },
     'policy:basic': {
         'realm': 'Pyramid-Helpers Application',
     },
+    'policy:cookie': {
+        'secret': 'the-big-secret-for-secured-authentication',
+        'hashalg': 'sha512',
+    },
     'policy:remote': {
         'fake_user': None,
         'header': None,
         'login_url': None,
         'logout_url': None,
     },
-    'policy:ticket': {
-        'secret': 'the-big-secret-for-secured-authentication',
-        'hashalg': 'sha512',
-    },
     'policy:token': {
         'header': 'X-PH-Authentication-Token',
         'query_param': None,
@@ -81,24 +81,24 @@ SETTINGS_DEFAULTS = {
 SETTINGS_RULES = {
     'auth': [
         ('enabled', (bool, NoneType), 'enabled must be a boolean or an integer'),
+        ('backend', (str, NoneType), 'backend must be a string designating a valid backend'),
         ('policies', (list, NoneType), 'policies must be a comma separated list of policies'),
-        ('mode', (str, NoneType), 'mode must be a string designating a valid mode'),
         ('get_principals', (str,), 'get_principals must be a string designating a valid callback'),
         ('get_user_by_username', (str,), 'get_user_by_username must be a string designating a valid callback'),
     ],
     'policy:basic': [
         ('realm', (str, NoneType), 'realm must be a string designating a realm authentication'),
     ],
+    'policy:cookie': [
+        ('secret', (str, NoneType), 'secret must be a string designating a secret'),
+        ('hashalg', (str, NoneType), 'hashalg must be a string designating a valid hashalg'),
+    ],
     'policy:remote': [
         ('fake_user', (str, NoneType), 'fake_user must be a string designating a username'),
         ('header', (str, NoneType), 'header must be a string designating a HTTP header'),
         ('login_url', (str, NoneType), 'login_url must be a string designating a valid url'),
         ('logout_url', (str, NoneType), 'logout_url must be a string designating a valid url'),
     ],
-    'policy:ticket': [
-        ('secret', (str, NoneType), 'secret must be a string designating a secret'),
-        ('hashalg', (str, NoneType), 'hashalg must be a string designating a valid hashalg'),
-    ],
     'policy:token': [
         ('header', (str, NoneType), 'header must be a string designating a HTTP header'),
         ('query_param', (str, NoneType), 'query_param must be a string designating a query parameter'),
@@ -110,10 +110,10 @@ SETTINGS_RULES = {
 log = logging.getLogger(__name__)
 
 
-class AuthenticationClient:
-    """ Authentication client base class """
+class AuthenticationBackend:
+    """ Authentication backend base class """
 
-    __auth_mode__ = None
+    __name__ = None
 
     def __enter__(self):
         """
@@ -131,20 +131,20 @@ class AuthenticationClient:
 
     # pylint: disable=unused-argument
     def setup(self, *args, **kwargs):
-        """ Register authentication client """
+        """ Register authentication backend """
 
-        if self.__auth_mode__ is None:
-            log.error('[AUTH] Attribute `.__auth_mode__` of AuthenticationClient instance must be set')
+        if self.__name__ is None:
+            log.error('[AUTH] Attribute `.__name__` of AuthenticationBackend instance must be set')
             return False
 
-        if self.__auth_mode__ in AUTH_CLIENTS:
-            log.error('[AUTH] An authentication client is already registered for mode %s', self.__auth_mode__)
+        if self.__name__ in BACKENDS:
+            log.error('[AUTH] An authentication backend is already registered for %s', self.__name__)
             return False
 
         # Registering object
-        AUTH_CLIENTS[self.__auth_mode__] = self
+        BACKENDS[self.__name__] = self
 
-        log.info('[AUTH] Registered authentication client, mode=%s, client=%s', self.__auth_mode__, self.__class__.__name__)
+        log.info('[AUTH] Registered authentication backend, name=%s, class=%s', self.__name__, self.__class__.__name__)
 
         return True
 
@@ -157,13 +157,13 @@ class AuthenticationClient:
 class MultiSecurityPolicy:
     """
     A Pyramid security policy that implements the following protocols:
-     * ticket
-     * remote
      * basic
+     * cookie
+     * remote
      * token
     """
 
-    POLICIES = ['ticket', 'remote', 'basic', 'token']
+    POLICIES = ['cookie', 'basic', 'remote', 'token']
 
     # pylint: disable=too-many-arguments, no-self-use
     def __init__(self, policies, hashalg='sha512', realm='Pyramid Helpers', secret=None):
@@ -172,7 +172,7 @@ class MultiSecurityPolicy:
             if policy not in self.POLICIES:
                 raise ConfigurationError(f'[AUTH] Invalid policy: {policy}')
 
-        self.cookie = AuthTktCookieHelper(secret, hashalg=hashalg) if 'ticket' in policies else None
+        self.cookie = AuthTktCookieHelper(secret, hashalg=hashalg) if 'cookie' in policies else None
         self.policies = policies
         self.realm = realm
 
@@ -220,7 +220,7 @@ class MultiSecurityPolicy:
                 policy = 'token'
 
             elif self.cookie:
-                policy = 'ticket'
+                policy = 'cookie'
 
         if policy not in self.policies:
             policy = self.policies[0]
@@ -250,7 +250,7 @@ class MultiSecurityPolicy:
                 identity = None
 
         else:
-            # Ticket
+            # Cookie
             identity = self.cookie.identify(request)
 
         if identity is None:
@@ -284,7 +284,7 @@ class MultiSecurityPolicy:
     def remember(self, request, username, **kw):
         """ Get set of headers suitable for «remembering« the user id """
 
-        if request.authentication_policy != 'ticket':
+        if request.authentication_policy != 'cookie':
             # Do nothing
             return []
 
@@ -333,17 +333,17 @@ def auth_header_user_tween_factory(handler, registry):
 
 
 def check_credentials(username, password, request):
-    """ Check extracted credential using configured mode """
+    """ Check extracted credential using configured backend """
 
     params = get_settings(request, 'auth', 'auth')
 
-    auth_client = AUTH_CLIENTS.get(params['mode'])
-    if auth_client is None:
-        # Invalid mode
+    backend_ = BACKENDS.get(params['backend'])
+    if backend_ is None:
+        # Invalid backend
         return False
 
-    with auth_client as client:
-        return client.validate_password(username, password, request)
+    with backend_ as backend:
+        return backend.validate_password(username, password, request)
 
 
 def extract_token(request):
@@ -435,16 +435,16 @@ def includeme(config):
             if policy not in MultiSecurityPolicy.POLICIES:
                 raise ConfigurationError(f'[AUTH] Invalid policy for parameters policies in section [auth]: {policy}')
 
-    # Check mode
-    if settings['auth']['mode'] is None:
-        raise ConfigurationError('[AUTH] Missing value for parameter mode in section [auth]')
+    # Check backend
+    if settings['auth']['backend'] is None:
+        raise ConfigurationError('[AUTH] Missing value for parameter backend in section [auth]')
 
-    if settings['auth']['mode'] not in AUTH_CLIENTS:
-        raise ConfigurationError(f'[AUTH] Invalid value for parameter mode in section [auth]: {settings["auth"]["mode"]}')
+    if settings['auth']['backend'] not in BACKENDS:
+        raise ConfigurationError(f'[AUTH] Invalid value for parameter backend in section [auth]: {settings["auth"]["backend"]}')
 
     # Check hashalg
-    if settings['policy:ticket']['hashalg'] not in hashlib.algorithms_available:
-        raise ConfigurationError(f'[AUTH] Invalid value for parameter hashalg in section [policy:ticket]: {settings["auth"]["policy:ticket"]["hashalg"]}')
+    if settings['policy:cookie']['hashalg'] not in hashlib.algorithms_available:
+        raise ConfigurationError(f'[AUTH] Invalid value for parameter hashalg in section [policy:cookie]: {settings["auth"]["policy:cookie"]["hashalg"]}')
 
     # Resolve get_principals
     func = resolve_dotted(settings['auth']['get_principals'])
@@ -485,9 +485,9 @@ def includeme(config):
     # Set security policy
     config.set_security_policy(MultiSecurityPolicy(
         settings['auth']['policies'],
-        hashalg=settings['policy:ticket']['hashalg'],
+        hashalg=settings['policy:cookie']['hashalg'],
         realm=settings['policy:basic']['realm'],
-        secret=settings['policy:ticket']['secret'],
+        secret=settings['policy:cookie']['secret'],
     ))
 
-    log.info('[AUTH] Initialization complete: policies=%s, mode=%s', settings['auth']['policies'], settings['auth']['mode'])
+    log.info('[AUTH] Initialization complete: policies=%s, backend=%s', settings['auth']['policies'], settings['auth']['backend'])
