@@ -4,7 +4,7 @@
 # By: Cyril Lacoux <clacoux@easter-eggs.com>
 #     Valéry Febvre <vfebvre@easter-eggs.com>
 #
-# Copyright (C) 2011-2021 Cyril Lacoux, Easter-eggs
+# Copyright (C) 2011-2022 Cyril Lacoux, Easter-eggs
 # https://gitlab.com/yack/pyramid-helpers
 #
 # This file is part of pyramid-helpers.
@@ -58,7 +58,7 @@ class Color(formencode.FancyValidator):
     # pylint: disable=unused-argument, no-self-use
     def _convert_from_python(self, value, state):
         if isinstance(value, (list, tuple)):
-            value = '#{0:02x}{1:02x}{2:02x}'.format(*value)
+            value = f'#{value[0]:02x}{value[1]:02x}{value[2]:02x}'
 
         return value
 
@@ -183,7 +183,7 @@ class Month(formencode.FancyValidator):
     # pylint: disable=unused-argument, no-self-use
     def _convert_from_python(self, value, state):
         if isinstance(value, (list, tuple)):
-            value = '{0:04d}-{1:02d}'.format(*value)
+            value = f'{value[0]:04d}-{value[1]:02d}'
 
         return value
 
@@ -220,7 +220,7 @@ class Time(formencode.FancyValidator):
     # pylint: disable=unused-argument, no-self-use
     def _convert_from_python(self, value, state):
         if isinstance(value, (list, tuple)):
-            value = '{0:02d}:{1:02d}'.format(*value)
+            value = f'{value[0]:02d}:{value[1]:02d}'
 
         return value
 
@@ -259,7 +259,7 @@ class Week(formencode.FancyValidator):
     # pylint: disable=unused-argument, no-self-use
     def _convert_from_python(self, value, state):
         if isinstance(value, (list, tuple)):
-            value = '{0:04d}-W{1:02d}'.format(*value)
+            value = f'{value[0]:04d}-W{value[1]:02d}'
 
         return value
 
