@@ -39,7 +39,7 @@ from sqlalchemy.types import Integer
 from sqlalchemy.types import Text
 from sqlalchemy.types import Unicode
 
-from pyramid_helpers.auth import AuthenticationClient
+from pyramid_helpers.auth import AuthenticationBackend
 from pyramid_helpers.models import Base
 from pyramid_helpers.models import DBSession
 
@@ -59,12 +59,12 @@ user_groups_associations = Table(
 )
 
 
-class DatabaseAuthenticationClient(AuthenticationClient):
-    """ Authentication client for database """
+class DatabaseAuthenticationBackend(AuthenticationBackend):
+    """ Authentication backend for database """
 
     # pylint: disable=too-few-public-methods
 
-    __auth_mode__ = 'database'
+    __name__ = 'database'
 
     # pylint: disable=no-self-use,unused-argument
     def validate_password(self, username, password, request):
