@@ -4,7 +4,7 @@
 # By: Cyril Lacoux <clacoux@easter-eggs.com>
 #     Valéry Febvre <vfebvre@easter-eggs.com>
 #
-# Copyright (C) 2011-2021 Cyril Lacoux, Easter-eggs
+# Copyright (C) 2011-2022 Cyril Lacoux, Easter-eggs
 # https://gitlab.com/yack/pyramid-helpers
 #
 # This file is part of pyramid-helpers.
@@ -50,7 +50,7 @@ class EnumPredicate:
 
     def text(self):
         """ Predicate identifier """
-        return '{0}'.format(self.params)
+        return str(self.params)
 
     phash = text
 
@@ -81,7 +81,7 @@ class NumericPredicate:
 
     def text(self):
         """ Predicate identifier """
-        return '{0}'.format(self.names)
+        return str(self.names)
 
     phash = text
 
@@ -96,11 +96,5 @@ def includeme(config):
     config.include('pyramid_helpers.predicates')
     """
 
-    registry = config.registry
-    settings = registry.settings
-
-    if settings.get('predicates.enabled', 'false').lower() not in ('true', 'yes'):
-        return
-
     config.add_route_predicate('enum_predicate', EnumPredicate)
     config.add_route_predicate('numeric_predicate', NumericPredicate)
