@@ -37,7 +37,7 @@ from pyrad.dictionary import Dictionary
 from pyrad.packet import AccessAccept
 from pyrad.packet import AccessRequest
 
-from pyramid_helpers.auth import AuthenticationClient
+from pyramid_helpers.auth import AuthenticationBackend
 from pyramid_helpers.utils import ConfigurationError
 from pyramid_helpers.utils import get_settings
 from pyramid_helpers.utils import parse_settings
@@ -87,10 +87,10 @@ class RadiusError(Exception):
     """ RADIUS error """
 
 
-class RadiusClient(AuthenticationClient):
+class RadiusClient(AuthenticationBackend):
     """ RADIUS authentication client """
 
-    __auth_mode__ = 'radius'
+    __name__ = 'radius'
 
     def __init__(self):
         """ RADIUS initialization """
