@@ -25,10 +25,10 @@
 
 function partialLinkSetup() {
     $('a.partial-link').css({'outline': 'none'}).click(function(event) {
-        var url = $(this).attr('href');
-        var target = $(this).parents('div.partial-block:first');
-        var partialKey = target.data('partial-key');
-        var data = {};
+        let url = $(this).attr('href');
+        let target = $(this).parents('div.partial-block:first');
+        let partialKey = target.data('partial-key');
+        let data = {};
 
         data[partialKey] = true;
 
